@@ -16,8 +16,9 @@ nltk.download('stopwords')
 stemmer = stemmer("english")
 
 ## Import C++ functions
-preproc_cpp = cppimport.imp("hdproc/hdp_preproc")
-
+#preproc_cpp = cppimport.imp("../hdp_preproc")
+import os
+os.getcwd()
 
 #### MAIN FUNCTIONS ####
 
